@@ -16,7 +16,8 @@ import atexit
 
 
 def start_headless(
-    mm_app_path, config_file, java_loc=None, core_log_path=None, buffer_size_mb=1024, port=Bridge.DEFAULT_PORT
+    mm_app_path, config_file, java_loc=None, core_log_path=None, buffer_size_mb=1024,
+        port=Bridge.DEFAULT_PORT,timeout=Bridge.DEFAULT_TIMEOUT
 ):
     """
     Start a Java process that contains the neccessary libraries for pycro-manager to run,
@@ -73,7 +74,7 @@ def start_headless(
     atexit.register(lambda: p.terminate())
 
     # Initialize core
-    with Bridge(port=port) as bridge:
+    with Bridge(port=port, timeout=timeout) as bridge:
         core = bridge.get_core()
 
         core.wait_for_system()
@@ -90,7 +91,7 @@ def start_headless(
 ### These functions outside class to prevent problems with pickling when running them in differnet process
 
 
-def _event_sending_fn(bridge_port, event_port, event_queue, debug=False):
+def _event_sending_fn(bridge_port, event_port, event_queue, bridge_timeout=Bridge.DEFAULT_TIMEOUT, debug=False):
     """
 
     Parameters
@@ -106,7 +107,8 @@ def _event_sending_fn(bridge_port, event_port, event_queue, debug=False):
     -------
 
     """
-    with Bridge(debug=debug, port=bridge_port) as bridge:
+
+    with Bridge(debug=debug, port=bridge_port, timeout=bridge_timeout) as bridge:
         bridge._test_id = 'events'
         event_socket = bridge._connect_push(event_port)
         while True:
@@ -123,6 +125,7 @@ def _event_sending_fn(bridge_port, event_port, event_queue, debug=False):
                 print("sent events")
 
 
+
 def _acq_hook_startup_fn(bridge_port, pull_port, push_port, hook_connected_evt, event_queue, hook_fn, debug):
     """
 
@@ -241,7 +244,13 @@ def _processor_startup_fn(
                 "but instead they were {} and {}".format(image_tags_tuple[0].dtype, pixels.dtype)
             )
 
-        metadata["PixelType"] = "GRAY8" if pixels.dtype.itemsize == 1 else "GRAY16"
+        if metadata['PixelType'] == 'RGB32':
+            if pixels.shape[-1] == 3:
+                #append 0 for alpha channel because thats whats expected
+                pixels = np.concatenate([pixels, np.zeros_like(pixels[..., 0])[..., None]], axis=2)
+        else:
+            #maybe pixel type was changed by processing?
+            metadata["PixelType"] = "GRAY8" if pixels.dtype.itemsize == 1 else "GRAY16"
 
         processed_img = {
             "pixels": pixels.tobytes(),
@@ -262,7 +271,10 @@ def _processor_startup_fn(
 
         metadata = message["metadata"]
         pixels = deserialize_array(message["pixels"])
-        image = np.reshape(pixels, [metadata["Height"], metadata["Width"]])
+        if metadata['PixelType'] == 'RGB32':
+            image = np.reshape(pixels, [metadata["Height"], metadata["Width"], 4])[..., :3]
+        else:
+            image = np.reshape(pixels, [metadata["Height"], metadata["Width"]])
 
         params = signature(process_fn).parameters
         if len(params) == 2 or len(params) == 4:
@@ -310,6 +322,7 @@ class Acquisition(object):
         magellan_explore=False,
         process=False,
         saving_queue_size=20,
+        bridge_timeout=500,
         port=Bridge.DEFAULT_PORT,
         debug=False,
         core_log_debug=False,
@@ -381,6 +394,8 @@ class Acquisition(object):
             The number of images to queue (in memory) while waiting to write to disk. Higher values should
             in theory allow sequence acquisitions to go faster, but requires the RAM to hold images while
             they are waiting to save
+        bridge_timeout :
+            Timeout in ms of all operations going throught the Bridge
         port :
             Allows overriding the defualt port for using Java side servers on a different port
         debug : bool
@@ -388,7 +403,8 @@ class Acquisition(object):
         core_log_debug : bool
             Print debug messages on java side in the micro-manager core log
         """
-        self.bridge = Bridge(debug=debug, port=port)
+        self._bridge_timeout = bridge_timeout
+        self.bridge = Bridge(debug=debug, port=port, timeout=bridge_timeout)
         self._bridge_port = port
         self._debug = debug
         self._dataset = None
@@ -488,7 +504,7 @@ class Acquisition(object):
 
             self._event_thread = threading.Thread(
                 target=_event_sending_fn,
-                args=(self._bridge_port, self.event_port, self._event_queue, self._debug),
+                args=(self._bridge_port, self.event_port, self._event_queue, self._bridge_timeout, self._debug),
                 name="Event sending",
             )
             self._event_thread.start()
