@@ -23,6 +23,7 @@ class DataSocket:
         self._debug = debug
         # store these as wekrefs so that circular refs dont prevent garbage collection
         self._java_objects = WeakSet()
+        self._port = port
         if type == zmq.PUSH:
             if debug:
                 print("binding {}".format(port))
@@ -175,6 +176,11 @@ class DataSocket:
         for java_object in self._java_objects:
             java_object._close()
         self._socket.close()
+        while not self._socket.closed:
+            time.sleep(0.01)
+        self._socket = None
+        if self._debug:
+            print('closed socket {}'.format(self._port))
 
 
 class Bridge:
@@ -187,7 +193,7 @@ class Bridge:
 
     DEFAULT_PORT = 4827
     DEFAULT_TIMEOUT = 500
-    _EXPECTED_ZMQ_SERVER_VERSION = "4.0.0"
+    _EXPECTED_ZMQ_SERVER_VERSION = "4.1.0"
 
     thread_local = threading.local()
 
@@ -200,6 +206,9 @@ class Bridge:
             Bridge.thread_local.bridge_count[port] += 1
             return Bridge.thread_local.bridge[port]
         else:
+            if (not hasattr(Bridge.thread_local, "bridge_count")) or Bridge.thread_local.bridge_count is None:
+                Bridge.thread_local.bridge_count = {}
+            Bridge.thread_local.bridge_count[port] = 1
             return super(Bridge, cls).__new__(cls)
 
     def __init__(
@@ -226,8 +235,8 @@ class Bridge:
         #     return  ### What was this supposed to do?
         if not hasattr(Bridge.thread_local, "bridge") or Bridge.thread_local.bridge is None:
             Bridge.thread_local.bridge = {}
-            Bridge.thread_local.bridge_count = {port: 1}
         Bridge.thread_local.bridge[port] = self  # cache a thread-local version of the bridge
+
         self._convert_camel_case = convert_camel_case
         self._debug = debug
         self._timeout = timeout
@@ -264,11 +273,15 @@ class Bridge:
     def close(self):
         Bridge.thread_local.bridge_count[self._port] -= 1
         if Bridge.thread_local.bridge_count[self._port] == 0:
+            del Bridge.thread_local.bridge_count[self._port]
+            del Bridge.thread_local.bridge[self._port]
             self._master_socket.close()
             self._master_socket = None
-            Bridge.thread_local.bridge = None
             self._closed = True
 
+        if len(Bridge.thread_local.bridge) == 0:
+            Bridge.thread_local.bridge = None
+            Bridge.thread_local.bridge_count = None
 
 
     def get_class(self, serialized_object) -> typing.Type["JavaObjectShadow"]:
